==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/DropdownItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DropdownItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DropdownItem, _super);
    function DropdownItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(DropdownItem.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.a.n = this.f;
        },
        enumerable: false,
        configurable: true
    });
    DropdownItem.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DropdownItem.prototype, "h", {
        get: function () {
            var ret_ = this.b.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "e", {
        get: function () {
            var ret_ = this.b.m("selected");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("selected", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "c", {
        get: function () {
            var ret_ = this.b.m("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "d", {
        get: function () {
            var ret_ = this.b.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    DropdownItem.prototype.i = function () {
        this.nativeElement.connectedCallback();
    };
    DropdownItem.$t = markType(DropdownItem, 'DropdownItem', BaseElement.$);
    return DropdownItem;
}(BaseElement));
export { DropdownItem };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/DropdownItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DropdownItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DropdownItem, _super);
    function DropdownItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(DropdownItem.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.a.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    DropdownItem.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DropdownItem.prototype, "h", {
        get: function () {
            var ret_ = this.b.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "e", {
        get: function () {
            var ret_ = this.b.n("selected");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("selected", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "c", {
        get: function () {
            var ret_ = this.b.n("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownItem.prototype, "d", {
        get: function () {
            var ret_ = this.b.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    DropdownItem.prototype.i = function () {
        this.nativeElement.connectedCallback();
    };
    DropdownItem.$t = markType(DropdownItem, 'DropdownItem', BaseElement.$);
    return DropdownItem;
}(BaseElement));
export { DropdownItem };
